@@ -18,7 +18,7 @@
 """
 
 __author__ = "Guewen Baconnier <guewen.baconnier@gmail.com>"
-__version__ = "0.6.0"
+__version__ = "0.6.1"
 
 import urllib
 import warnings
@@ -61,7 +61,7 @@ class PrestaShopWebService(object):
     """
 
     MIN_COMPATIBLE_VERSION = '1.4.0.17'
-    MAX_COMPATIBLE_VERSION = '1.5.5.0'
+    MAX_COMPATIBLE_VERSION = '1.5.9.0'
 
     def __init__(self, api_url, api_key, debug=False, headers=None, client_args=None):
         """
@@ -107,7 +107,7 @@ class PrestaShopWebService(object):
         if self.headers is None:
             self.headers = {'User-agent': 'Prestapyt: Python Prestashop Library'}
 
-    def _check_status_code(self, status_code):
+    def _check_status_code(self, status_code, content):
         """
         Take the status code and throw an exception if the server didn't return 200 or 201 code
         @param status_code: status code returned by the server
@@ -119,21 +119,15 @@ class PrestaShopWebService(object):
                            404: 'Not Found',
                            405: 'Method Not Allowed',
                            500: 'Internal Server Error',}
-
-        error_label = ('This call to PrestaShop Web Services failed and '
-                       'returned an HTTP status of %d. That means: %s.')
+        error_label = ('PrestaShop error: %d %s. %s')
         if status_code in (200, 201):
             return True
         elif status_code == 401:
-            raise PrestaShopAuthenticationError(error_label
-                                % (status_code, message_by_code[status_code]), status_code)
+            raise PrestaShopAuthenticationError(error_label % (status_code, message_by_code[status_code], ''), status_code)
         elif status_code in message_by_code:
-            raise PrestaShopWebServiceError(error_label
-                    % (status_code, message_by_code[status_code]), status_code)
+            raise PrestaShopWebServiceError(error_label % (status_code, message_by_code[status_code], self._parse_error(content)), status_code)
         else:
-            raise PrestaShopWebServiceError(("This call to PrestaShop Web Services returned "
-                                            "an unexpected HTTP status of: %d")
-                                            % (status_code,), status_code)
+            raise PrestaShopWebServiceError(error_label % (status_code, message_by_code[status_code], self._parse_error(content)), status_code)
 
     def _check_version(self, version):
         """
@@ -143,13 +137,30 @@ class PrestaShopWebService(object):
         @return: True if the library is compatible. Otherwise raise an error PrestaShopWebServiceError
         """
         if version:
-            if not (LooseVersion(self.MIN_COMPATIBLE_VERSION) <
-                    LooseVersion(version) <
+            if not (LooseVersion(self.MIN_COMPATIBLE_VERSION) <=
+                    LooseVersion(version) <=
                     LooseVersion(self.MAX_COMPATIBLE_VERSION)):
                 warnings.warn(("This library may not be compatible with this version of PrestaShop (%s). "
                      "Please upgrade/downgrade this library") % (version,))
         return True
 
+    def _parse_error(self, xml_content):
+        """
+        Take the XML content as string and extracts the PrestaShop error
+        @param xml_content: xml content returned by the PS server as string
+        @return prestashop_error_message
+        """
+        answer    = self._parse(xml_content)
+        error_msg = ''
+        if isinstance(answer, dict):
+            errors = answer.get('prestashop', {}).get('errors', {}).get('error', {})
+            if isinstance(errors, list):
+                for error in errors:
+                    error_msg += '%s ' % (error.get('message'))
+            elif isinstance(errors, dict):
+                error_msg = errors.get('message')
+        return error_msg
+
     def _execute(self, url, method, body=None, add_headers=None):
         """
         Execute a request on the PrestaShop Webservice
@@ -166,6 +177,8 @@ class PrestaShopWebService(object):
             self.http_client = httplib2.Http(**self.client_args)
             # Prestashop use the key as username without password
             self.http_client.add_credentials(self._api_key, False)
+            if hasattr(self.http_client, "set_auth_type"):
+                self.http_client.set_auth_type("basic")
             self.http_client.follow_all_redirects = True
 
         if self.debug:
@@ -181,7 +194,7 @@ class PrestaShopWebService(object):
             print ("Response code: %s\nResponse headers:\n%s\nResponse body:\n%s"
                    % (status_code, header, content))
 
-        self._check_status_code(status_code)
+        self._check_status_code(status_code, content)
         self._check_version(header.get('psws-version'))
         return status_code, header, content
 
@@ -199,6 +212,8 @@ class PrestaShopWebService(object):
             parsed_content = ElementTree.fromstring(content)
         except ExpatError, err:
             raise PrestaShopWebServiceError('HTTP XML response is not parsable : %s' % (err,))
+        except ElementTree.ParseError as e:
+            raise PrestaShopWebServiceError('HTTP XML response is not parsable : %s. %s' % (e, content[:512]))
 
         return parsed_content
 
